summaryrefslogtreecommitdiffstats
path: root/remoting/client/jingle_host_connection.h
diff options
context:
space:
mode:
authorsergeyu@chromium.org <sergeyu@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-10-27 19:11:44 +0000
committersergeyu@chromium.org <sergeyu@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-10-27 19:11:44 +0000
commitd6e6d13cb35c8e1dabd3eca5d03cf5d2c84abf54 (patch)
tree41bdaf07363bf6030ac9025a6d291201fa121684 /remoting/client/jingle_host_connection.h
parent9593bd2d1813e5096b442a276b3a5b7b5408bf6a (diff)
downloadchromium_src-d6e6d13cb35c8e1dabd3eca5d03cf5d2c84abf54.zip
chromium_src-d6e6d13cb35c8e1dabd3eca5d03cf5d2c84abf54.tar.gz
chromium_src-d6e6d13cb35c8e1dabd3eca5d03cf5d2c84abf54.tar.bz2
Cleanups in the chromotocol code.
1) Renamed ChromotingServer to ChromotocolServer. 2) Renamed ChromotingConnection to ChromotocolConnection. 3) Added documentation for ChromotocolServer. 4) Fixed methods names in ChromtocolConnection. 5) Removed some unncessary references to media/*. BUG=None TEST=None Review URL: http://codereview.chromium.org/4105002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@64113 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'remoting/client/jingle_host_connection.h')
-rw-r--r--remoting/client/jingle_host_connection.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/remoting/client/jingle_host_connection.h b/remoting/client/jingle_host_connection.h
index a72d8a9..ee5240f 100644
--- a/remoting/client/jingle_host_connection.h
+++ b/remoting/client/jingle_host_connection.h
@@ -25,8 +25,8 @@
#include "remoting/client/client_context.h"
#include "remoting/client/host_connection.h"
#include "remoting/jingle_glue/jingle_client.h"
-#include "remoting/protocol/chromoting_connection.h"
-#include "remoting/protocol/chromoting_server.h"
+#include "remoting/protocol/chromotocol_connection.h"
+#include "remoting/protocol/chromotocol_server.h"
#include "remoting/protocol/stream_reader.h"
#include "remoting/protocol/stream_writer.h"
@@ -53,13 +53,13 @@ class JingleHostConnection : public HostConnection,
// JingleClient::Callback interface.
virtual void OnStateChange(JingleClient* client, JingleClient::State state);
// Callback for ChromotingServer.
void OnNewChromotocolConnection(
- ChromotingConnection* connection,
- ChromotingServer::NewConnectionResponse* response);
+ ChromotocolConnection* connection,
+ ChromotocolServer::IncomingConnectionResponse* response);
- // Callback for ChromotingConnection.
- void OnConnectionStateChange(ChromotingConnection::State state);
+ // Callback for ChromotocolConnection.
+ void OnConnectionStateChange(ChromotocolConnection::State state);
private:
// The message loop for the jingle thread this object works on.
@@ -81,8 +81,8 @@ class JingleHostConnection : public HostConnection,
ClientContext* context_;
scoped_refptr<JingleClient> jingle_client_;
- scoped_refptr<ChromotingServer> chromotocol_server_;
- scoped_refptr<ChromotingConnection> connection_;
+ scoped_refptr<ChromotocolServer> chromotocol_server_;
+ scoped_refptr<ChromotocolConnection> connection_;
EventStreamWriter event_writer_;
VideoStreamReader video_reader_;
@@ -53,13 +53,13 @@ class JingleHostConnection : public HostConnection,
// JingleClient::Callback interface.
virtual void OnStateChange(JingleClient* client, JingleClient::State state);
- // Callback for ChromotingServer.
+ // Callback for ChromotocolServer.
void OnNewChromotocolConnection(